==> ssreflect_1.10.0+dfsg.orig.tar.gz: math-comp-mathcomp-1.10.0/etc/ANNOUNCE-github.md <==
# The Mathematical Components github organization

We are plase to announce that the development of the Mathematical Components now
happens in the public and takes advantage of github's organization system.
The purpose of such organization is to create a synergy between the Mathematical Components
library and its ecosystem of related projects.

The [homepage](http://math-comp.github.io/math-comp/) is now hosted by the
github.io service, and the [main archive](https://github.com/math-comp/math-comp)
is available as a  git repository in the [organization space](https://github.com/math-comp/).
We accept bug reports and pull requests via the standard github interface.

Users of the library are encouraged to join the organization and place (or mirror) their projects
in the organization name space.  The immediate gain is discoverability.  The more long term deal
we propose is that the impact of non backward compatible changes in the Mathematical Components
library will be carefully assessed on all the mature projects part of the organization.  In
exchange we expect members of the organization to actively maintain their code when a breaking
change is applied or a patch is proposed.

The organization hosts a [wiki](https://github.com/math-comp/wiki/wiki) for exchanging tips
and tricks, gotchas, good practices, etc.

The ssreflect [mailing list](https://sympa.inria.fr/sympa/info/ssreflect) shall serve as the
privileged communication channel between the organization members. Contact us on this channel
to join the organization or to get write access to the wiki.

-- The Mathematical Components team

==> ssreflect_2.3.0.orig.tar.gz: math-comp-mathcomp-2.3.0/etc/ANNOUNCE-github.md <==
# The Mathematical Components github organization

We are pleased to announce that the development of the Mathematical Components now
happens in the public and takes advantage of github's organization system.
The purpose of such organization is to create a synergy between the Mathematical Components
library and its ecosystem of related projects.

The [homepage](http://math-comp.github.io/math-comp/) is now hosted by the
github.io service, and the [main archive](https://github.com/math-comp/math-comp)
is available as a  git repository in the [organization space](https://github.com/math-comp/).
We accept bug reports and pull requests via the standard github interface.

Users of the library are encouraged to join the organization and place (or mirror) their projects
in the organization name space.  The immediate gain is discoverability.  The more long term deal
we propose is that the impact of non backward compatible changes in the Mathematical Components
library will be carefully assessed on all the mature projects part of the organization.  In
exchange we expect members of the organization to actively maintain their code when a breaking
change is applied or a patch is proposed.

The organization hosts a [wiki](https://github.com/math-comp/wiki/wiki) for exchanging tips
and tricks, gotchas, good practices, etc.

The ssreflect [mailing list](https://sympa.inria.fr/sympa/info/ssreflect) shall serve as the
privileged communication channel between the organization members. Contact us on this channel
to join the organization or to get write access to the wiki.

-- The Mathematical Components team
